@@ -30,7 +30,6 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 
-#include <libtelepathy/tp-conn.h>
 #include <libmissioncontrol/mc-account-monitor.h>
 #include <libmissioncontrol/mission-control.h>
 
@@ -39,8 +38,7 @@
 #include "empathy-ui-utils.h"
 #include "empathy-account-chooser.h"
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EMPATHY_TYPE_ACCOUNT_CHOOSER, EmpathyAccountChooserPriv))
-
+#define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyAccountChooser)
 typedef struct {
 	MissionControl                 *mc;
 	McAccountMonitor               *monitor;
@@ -48,6 +46,7 @@ typedef struct {
 	gboolean                        has_all_option;
 	EmpathyAccountChooserFilterFunc filter;
 	gpointer                        filter_data;
+	gpointer                        token;
 } EmpathyAccountChooserPriv;
 
 typedef struct {
@@ -130,8 +129,10 @@ empathy_account_chooser_class_init (EmpathyAccountChooserClass *klass)
 static void
 empathy_account_chooser_init (EmpathyAccountChooser *chooser)
 {
-	EmpathyAccountChooserPriv *priv = GET_PRIV (chooser);
+	EmpathyAccountChooserPriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (chooser,
+		EMPATHY_TYPE_ACCOUNT_CHOOSER, EmpathyAccountChooserPriv);
 
+	chooser->priv = priv;
 	priv->set_active_item = FALSE;
 	priv->filter = NULL;
 	priv->filter_data = NULL;
@@ -152,10 +153,7 @@ account_chooser_finalize (GObject *object)
 	g_signal_handlers_disconnect_by_func (priv->monitor,
 					      account_chooser_account_deleted_cb,
 					      chooser);
-	dbus_g_proxy_disconnect_signal (DBUS_G_PROXY (priv->mc),
-					"AccountStatusChanged",
-					G_CALLBACK (account_chooser_status_changed_cb),
-					chooser);
+	empathy_disconnect_account_status_changed (priv->token);
 	g_object_unref (priv->mc);
 	g_object_unref (priv->monitor);
 
@@ -224,9 +222,9 @@ empathy_account_chooser_new (void)
 	g_signal_connect (priv->monitor, "account-deleted",
 			  G_CALLBACK (account_chooser_account_deleted_cb),
 			  chooser);
-	dbus_g_proxy_connect_signal (DBUS_G_PROXY (priv->mc), "AccountStatusChanged",
-				     G_CALLBACK (account_chooser_status_changed_cb),
-				     chooser, NULL);
+	priv->token = empathy_connect_to_account_status_changed (priv->mc,
+						   G_CALLBACK (account_chooser_status_changed_cb),
+						   chooser, NULL);
 
 	account_chooser_setup (EMPATHY_ACCOUNT_CHOOSER (chooser));
 
@@ -606,13 +604,16 @@ account_chooser_set_account_foreach (GtkTreeModel   *model,
 	gtk_tree_model_get (model, iter, COL_ACCOUNT_POINTER, &account, -1);
 
 	/* Special case so we can make it possible to select the All option */
-	if (!data->account && !account) {
-		equal = TRUE;
-	}
-	else if ((data->account && !account) || (!data->account && account)) {
+	if ((data->account == NULL) != (account == NULL)) {
 		equal = FALSE;
+	}
+	else if (data->account == account) {
+		equal = TRUE;
 	} else {
 		equal = empathy_account_equal (data->account, account);
+	}
+
+	if (account) {
 		g_object_unref (account);
 	}
 
